# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-File-Slurp
Version:	9999.32
Release:	10.%{__distinit}%{__distvers}
Summary:	Efficient Reading/Writing of Complete Files
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/File-Slurp
Source0:	https://cpan.metacpan.org/modules/by-module/File/File-Slurp-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Exporter) >= 5.57
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(File::Basename)
BuildRequires:	perl(File::Spec) >= 3.01
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(overload)
BuildRequires:	perl(POSIX)
BuildRequires:	perl(re)
BuildRequires:	perl(strict)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(lib)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(Socket)
BuildRequires:	perl(Symbol)
BuildRequires:	perl(Test::More)
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(B)

%description
This module provides subs that allow you to read or write entire files with
one simple call. They are designed to be simple to use, have flexible ways
to pass in or get the file contents and to be very efficient. There is also
a sub to read in all the files in a directory other than . and ..

These slurp/spew subs work for files, pipes and sockets, and stdio, 
pseudo-files, and DATA.

%prep
%setup -q -n File-Slurp-%{version}

# Fix line endings
sed -i -e 's|\r$||' Changes

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc Changes README.md
%{perl_vendorlib}/File/
%{_mandir}/man3/File::Slurp.3*

%changelog
* Mon Jul 17 2023 Paul Howarth <paul@city-fan.org> - 9999.32-10
- Use SPDX-format license tag

* Wed Jul  1 2020 Paul Howarth <paul@city-fan.org> - 9999.32-1
- Update to 9999.32
  - Re-release after fixing MANIFEST

* Tue Jun 30 2020 Paul Howarth <paul@city-fan.org> - 9999.31-1
- Update to 9999.31
  - Remove TravisCI and AppVeyor
  - Test using GitHub Actions/workflows on Windows, Mac, and Linux
  - Add See Also section to the docs (GH#24)
  - Add file existence and size checks (CPAN RT#132900)

* Mon Mar  9 2020 Paul Howarth <paul@city-fan.org> - 9999.30-1
- Update to 9999.30
  - Altered the atomic version of write_file to use temporary files that are
    also hidden files (CPAN RT#132064)

* Thu Nov 28 2019 Paul Howarth <paul@city-fan.org> - 9999.29-1
- Update to 9999.29
  - Correct some documentation errors where copy-paste had us saying File::Spec
    rather than File::Slurp (CPAN RT#131097)
  - Reduce the size of the tests in t/handle.t to be nicer to CPAN Testers

* Fri Sep 13 2019 Paul Howarth <paul@city-fan.org> - 9999.28-1
- Update to 9999.28
  - Stop testing with Taint mode (Taint was a terrible practice that should
    never ever ever have been a thing)

* Sat Apr  6 2019 Paul Howarth <paul@city-fan.org> - 9999.27-1
- Update to 9999.27
  - Update the documentation on the atomic write (the pid is no longer used)
    (CPAN RT#129029)
  - Localize $^W to stop File::Temp from warning the user when the -w flag is
    on while we're grabbing a temporary file name (CPAN RT#129029)

* Thu Feb 14 2019 Paul Howarth <paul@city-fan.org> - 9999.26-1
- Update to 9999.26
  - Reduce the size of handle.t to prevent failures on systems with limits set
  - Skip all tests in the suite that relied on overriding syswrite to test
    failure mechanisms as CORE::print cannot be overridden
  - Refactor write_file to use print rather than syswrite
    - When performing an atomic write, make sure we find a good temporary file
      so that we don't accidentally overwrite a file that may already exist in
      the working directory
    - Stop re-working the line endings on write_file when on Windows as the use
      of print now allows layers to provide that functionality
  - Add File::Basename, File::Spec, File::Temp, and IO::Handle to the runtime
    prereqs; these were already testing prereqs and are core
  - Perl 5.30 compliance is complete at this point
- Work around test suite's inability to turn off warnings in File::Temp prior
  to F-19, EL-8

* Mon Nov 19 2018 Paul Howarth <paul@city-fan.org> - 9999.25-1
- Update to 9999.25
  - The previous release contained nothing but a documentation update; that
    updated documentation erroneously mentioned pseudo-files, which are
    perfectly fine to use with File::Slurp
  - Add regression test for GLOB refs being slurped in (GH#17)
  - Refactor read_file to use open and read rather than sysopen and sysread
  - Add a bugwards compatible feature to keep track of the cursor when dealing
    with the DATA handle (GH#17)
  - Fix a typo in the documentation
- Get rid of spurious executable permissions on documentation files

* Tue Oct 30 2018 Paul Howarth <paul@city-fan.org> - 9999.24-1
- Update to 9999.24
  - Document the clear downfalls of using file handles of any kind rather than
    just the file's path string

* Mon Oct 22 2018 Paul Howarth <paul@city-fan.org> - 9999.23-1
- Update to 9999.23
  - Fix an error on the test rewrites with a bad value for binmode
  - Create a 00-report-prereqs.dd to ease testing on 5.6
  - Bump requirement for File::Spec to 3.01 as Cwd was shipped separately
    before and the one that came with 5.6 had Taint issues
  - Cleaned up the Change log to make all dates uniform

* Tue Oct 16 2018 Paul Howarth <paul@city-fan.org> - 9999.22-1
- Update to 9999.22
  - Update the SYNOPSIS documentation
  - Fix some EUMM metadata depending on version
  - Fix Windows path concatenation on read_dir
  - Document each function with proper POD heads and re-order in alphabetical
  - Dump the POD to GH markdown for a README.md
  - Remove the README file
  - Remove some work-arounds for older Perls < 5.6
  - Do not inherit from Exporter (requires Exporter 5.57)
  - Fix perms.t to run on all platforms (CPAN RT#92401)
  - Clean up handle.t (we no longer use the -w flag anywhere)

* Tue Oct  9 2018 Paul Howarth <paul@city-fan.org> - 9999.21-1
- Update to 9999.21
  - Fixed spelling mistakes in POD (CPAN RT#85251)
  - Fixed a typo in an example (CPAN RT#72116, CPAN RT#80279)
  - Remove documentation mentions of Perl < 5.006 as that's required
  - Fix POD coverage tests by adding a few more ignored functions
  - Added t/00-report-prereqs.t and t/edit_file.t
  - Move the POD tests to xt/author and added more xt/author tests
  - Fix all trailing whitespace in accordance with xt/author/eol.t
  - Updated the Makefile.PL to get all of the prereqs in there
  - Add CI testing via TravisCI and AppVeyor
  - Get rid of assumption of . in @INC in tests
  - Remove t/TestDriver.pm
  - Add t/lib/FileSlurpTest.pm
  - Make sure all tests use a properly acquired temporary file
  - Clean up prereqs a bit further
  - Document all failure cases in the 01-error* tests
  - Moved the CORE:: function overrides to their own test class to only be
    included when overriding is necessary
  - Unset $^W in a few strategic places to silence warnings when Test::Harness
    or ExtUtils::MakeMaker turn them on
  - Got rid of a few MYMETA leftovers in the MANIFEST
  - Add Git repository info to the Makefile
  - Add a contributors list for display on metacpan
- Switch upstream from search.cpan.org to metacpan.org
- Drop all patches, no longer needed
- Drop provides/requires filters, no longer needed
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section


* Thu Aug 25 2016 Paul Howarth <paul@city-fan.org> - 9999.19-15
- Classify buildreqs by usage
- Simplify find command using -delete
- Prefer %%global over %%define

* Sun Aug 31 2014 Paul Howarth <paul@city-fan.org> - 9999.19-10
- Drop %%defattr, redundant since rpm 4.4

* Sat Jun 23 2012 Paul Howarth <paul@city-fan.org> - 9999.19-4
- Patch around "subroutine redefined" warnings on old Perls
- BR: perl(Carp), perl(Data::Dumper), perl(Exporter), perl(IO::Handle),
  perl(lib) and perl(Socket)
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Drop patch for Perl 5.8.0 support
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Mon Jun 27 2011 Paul Howarth <paul@city-fan.org> - 9999.19-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jun  7 2011 Paul Howarth <paul@city-fan.org> - 9999.19-1
- Update to 9999.19:
  - Fixed use line in t/edit_file.t to import :edit first (CPAN RT#68229)
  - read_file and write_file work even when interrupted by signals
  - Fixed bugs in the config synopsis example
- Drop upstreamed patch for CPAN RT#68229

* Fri May 13 2011 Paul Howarth <paul@city-fan.org> - 9999.18-1
- Update to 9999.18:
  - Added :std and :edit export tags
  - Cleaned up EXPORT vars
  - Documented importing edit_file and edit_file_lines
  - Fixed some pod spelling
- Add patch to work around test incompatibility with Exporter < 5.58
  (CPAN RT#68229)

* Fri May 13 2011 Paul Howarth <paul@city-fan.org> - 9999.17-1
- Update to 9999.17:
  - Requiring Perl 5.6.2 (first time older Perls were dropped); this is because
    of use of the "re 'taint'" pragma
  - Added major new features: edit_file and edit_file_lines
  - Speed up of tainted slurp with return of lines
  - Added chomp option to read_file
  - Added prefix option to read_dir
  - Fixed optimization of reading small files
- Filter doc-file dependency perl(Symbol)

* Sun Apr 24 2011 Paul Howarth <paul@city-fan.org> - 9999.16-1
- Update to 9999.16:
  - Added support for read_file options to be a hash reference
  - Added support for read_dir options to be a hash reference
  - Added new feature prepend_file
  - Fixed bug with array_ref in list context, introduced by .15/.14
  - Cleaned up some pod

* Fri Mar 25 2011 Paul Howarth <paul@city-fan.org> - 9999.15-1
- Update to 9999.15:
  - Fixed error.t test so it works when run as root
  - Removed skip lines from error.t
  - Fixed POD about binmode option to reflect changes in 9999.14

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 9999.14-1
- Update to 9999.14:
  - Added LICENCE (same as perl) to POD
  - Added special faster code to slurp in small text files (a common case)
  - Rewrote the extras/slurp_bench.pl script, which now has a full legend,
    better CLI options, size is selectable, benchmark entries have more
    consistent names and it compares the new fast slurp for small files to the
    general slurp code
  - Cleaned up POD
  - Added more Synopsis examples
  - Added t/error.t to actually test error conditions; previous error.t was
    renamed to error_mode.t which better reflects its tests
  - t/error.t uses a new test driver module, which may get used by other tests
    in the future
  - Fixed check for SEEK_SET and other constant subs being defined
  - Added support for binmode other than :raw and binmode.t test
  - Added support for perms option in write_file and perms.t test
  - Added check to the rename call in atomic mode, tested in error.t.
  - Added POD to state that using scalar_ref or buf_ref will be faster and save
    memory due to not making a copy
  - read_file in list mode keeps data tainted
  - read_file checks for an overloaded object to get the file name
- Nobody else likes macros for commands
- Package TODO and experiment/ directory
- Filter bogus provides from extras/ directory
- Filter doc-file-dependency perl(base) from requires
- Recode Changes file as UTF-8
- Patch t/pseudo.t so that it can work with Perl 5.8.0

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 9999.13-9
- Import from Fedora

* Sat May  1 2010 Marcela Maslanova <mmaslano@redhat.com> - 9999.13-8
- Mass rebuild with perl-5.12.0

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 9999.13-7
- Rebuild against perl 5.10.1

* Sat Jul 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 9999.13-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 9999.13-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Jul  9 2008 Ralf Corsépius <rc040203@freenet.de> - 9999.13-4
- Re-activate tests

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 9999.13-3
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 9999.13-2
- Disable tests, due to wacky Fedora builders

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 9999.13-1
- Go to 9999.13 to fix build failures against perl 5.10.0

* Sun Jan 20 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 9999.12-4
- Rebuild for new perl

* Sun Sep  2 2007 Ralf Corsépius <rc040203@freenet.de> - 9999.12-3
- Update license tag
- BR: perl(ExtUtils::MakeMaker)

* Tue Sep  5 2006 Ralf Corsépius <rc040203@freenet.de> - 9999.12-2
- Mass rebuild

* Sat Mar 18 2006 Ralf Corsépius <rc040203@freenet.de> - 9999.12-1
- Upstream update

* Wed Mar  1 2006 Ralf Corsépius <rc040203@freenet.de> - 9999.11-2
- Rebuild for perl-5.8.8

* Wed Feb  1 2006 Ralf Corsépius <rc040203@freenet.de> - 9999.11-1
- Upstream update
- BR perl(Test::Pod), perl(Test::Pod::Coverage)
